import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.api_client import ApiClient, Endpoint as _Endpoint
from smscx_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from smscx_client.model.cancel_otp_response import CancelOtpResponse
from smscx_client.model.data_otp import DataOtp
from smscx_client.model.model400_invalid_param import Model400InvalidParam
from smscx_client.model.model401_unauthorized import Model401Unauthorized
from smscx_client.model.model403_insufficient_scope import Model403InsufficientScope
from smscx_client.model.model404_not_found import Model404NotFound
from smscx_client.model.model500_server_error import Model500ServerError
from smscx_client.model.new_otp_request import NewOtpRequest
from smscx_client.model.new_otp_response import NewOtpResponse
from smscx_client.model.verify_pin_request import VerifyPinRequest
from smscx_client.model.verify_pin_response import VerifyPinResponse


class OtpApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.cancel_otp_endpoint = _Endpoint(
            settings={
                'response_type': (CancelOtpResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/otp/{otpId}',
                'operation_id': 'cancel_otp',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'otp_id',
                ],
                'required': [
                    'otp_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'otp_id',
                ]
            },
            root_map={
                'validations': {
                    ('otp_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'otp_id':
                        (str,),
                },
                'attribute_map': {
                    'otp_id': 'otpId',
                },
                'location_map': {
                    'otp_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_otp_status_endpoint = _Endpoint(
            settings={
                'response_type': (DataOtp,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/otp/{otpId}',
                'operation_id': 'get_otp_status',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'otp_id',
                ],
                'required': [
                    'otp_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'otp_id',
                ]
            },
            root_map={
                'validations': {
                    ('otp_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'otp_id':
                        (str,),
                },
                'attribute_map': {
                    'otp_id': 'otpId',
                },
                'location_map': {
                    'otp_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.new_otp_endpoint = _Endpoint(
            settings={
                'response_type': (NewOtpResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/otp',
                'operation_id': 'new_otp',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'new_otp_request',
                ],
                'required': [
                    'new_otp_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'new_otp_request':
                        (NewOtpRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'new_otp_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.verify_otp_endpoint = _Endpoint(
            settings={
                'response_type': (VerifyPinResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/otp/{otpId}',
                'operation_id': 'verify_otp',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'otp_id',
                    'verify_pin_request',
                ],
                'required': [
                    'otp_id',
                    'verify_pin_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'otp_id',
                ]
            },
            root_map={
                'validations': {
                    ('otp_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'otp_id':
                        (str,),
                    'verify_pin_request':
                        (VerifyPinRequest,),
                },
                'attribute_map': {
                    'otp_id': 'otpId',
                },
                'location_map': {
                    'otp_id': 'path',
                    'verify_pin_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def cancel_otp(
        self,
        otp_id,
        **kwargs
    ):
        """Cancel OTP  # noqa: E501

        Cancel OTP request if a valid identifier was provided.    
### Errors for DELETE `/otp/{otpId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
| 404 | 2021 | not_found | Otp ID not found |  
| 403 | 2030 | access_denied | Otp already cancelled |  
| 403 | 2031 | access_denied | You cannot cancel a non-pending Otp |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.cancel_otp(otp_id, async_req=True)
        >>> result = thread.get()

        Args:
            otp_id (str): Identifier of the OTP request

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CancelOtpResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['otp_id'] = \
            otp_id
        return self.cancel_otp_endpoint.call_with_http_info(**kwargs)

    def get_otp_status(
        self,
        otp_id,
        **kwargs
    ):
        """Get OTP status  # noqa: E501

        Retrieves the details of OTP status if a valid identifier was provided.    ### Status for OTP requests  | Status | Description |  
|:------------:|:------------|  | PENDING | The OTP is pending validation by user |  | VERIFIED | The OTP was validated by user |  | EXPIRED | The validity of OTP has expired |  | CANCELLED | The OTP was cancelled by the user |  | FAILED | The OTP failed because too many unsuccessful attempts |    
### Errors for GET `/otp/{otpId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
| 404 | 2021 | not_found | Otp ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_otp_status(otp_id, async_req=True)
        >>> result = thread.get()

        Args:
            otp_id (str): Identifier of the OTP request

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DataOtp
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['otp_id'] = \
            otp_id
        return self.get_otp_status_endpoint.call_with_http_info(**kwargs)

    def new_otp(
        self,
        new_otp_request,
        **kwargs
    ):
        """New OTP  # noqa: E501

        Create a OTP request to verify a phone number.    <a name=\"otp-status\"></a>  ### Status for OTP requests  | Status | Description |  
|:------------:|:------------|  | PENDING | The OTP is pending validation by user |  | VERIFIED | The OTP was validated by user |  | EXPIRED | The validity of OTP has expired |  | CANCELLED | The OTP was cancelled by the user |  | FAILED | The OTP failed because too many unsuccessful attempts |    
### Errors for POST `/otp`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
| 400 | 2001 | invalid_param | The parameter 'phoneNumber' is empty or not set |  
| 400 | 2002 | invalid_param | The parameter 'countryIso' is empty or not set |  
| 400 | 2003 | invalid_param | Country ISO provided is invalid |  
| 400 | 2004 | invalid_param | The parameter 'from' is empty or not set |  
| 400 | 2005 | invalid_param | The parameter 'from' is not valid (min 3, max 15 characters) |  
| 400 | 2006 | invalid_param | The parameter 'template' is empty or not set |  
| 400 | 2006 | invalid_param | The parameter 'template' does not contain placeholder {{pin}} |  
| 400 | 2007 | invalid_param | The parameter 'ttl' is not a number |  
| 400 | 2008 | invalid_param | Min value for 'ttl' is 60 seconds |  
| 400 | 2009 | invalid_param | Max value for 'ttl' is 1800 seconds (30 mins) |  
| 400 | 2010 | invalid_param | The parameter 'maxAttempts' is not a number |  
| 400 | 2011 | invalid_param | Min value for 'maxAttempts' is 1 |  
| 400 | 2012 | invalid_param | Max value for 'maxAttempts' is 10 |  
| 400 | 2013 | invalid_param | The parameter 'pinType' is empty or not set |  
| 400 | 2014 | invalid_param | Invalid parameter 'pinType'. Must be one of: letters, numbers, alphanumeric |  
| 400 | 2015 | invalid_param | The parameter 'pinLength' is not a number |  
| 400 | 2016 | invalid_param | Min value for 'pinLength' is 4 |  
| 400 | 2017 | invalid_param | Max value for 'pinLength' is 10 |  
| 400 | 2018 | invalid_param | Track ID provided (parameter 'trackId') is not a valid UUID (v1-v5) |  
| 400 | 2019 | invalid_param | The parameter 'otpCallbackUrl' is not a valid URL |  
| 400 | 2020 | invalid_param | The phone number provided is invalid |    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.new_otp(new_otp_request, async_req=True)
        >>> result = thread.get()

        Args:
            new_otp_request (NewOtpRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            NewOtpResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['new_otp_request'] = \
            new_otp_request
        return self.new_otp_endpoint.call_with_http_info(**kwargs)

    def verify_otp(
        self,
        otp_id,
        pin,
        **kwargs
    ):
        """Verify OTP  # noqa: E501

        Verify the OTP received on the phone number.    
### Errors for POST `/otp/{otpId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
| 404 | 2021 | not_found | Otp ID not found |  
| 400 | 2022 | invalid_param | The parameter pin is empty or not set |  
| 400 | 2023 | otp_verified | The OTP was already verified |  
| 400 | 2024 | otp_cancelled | The OTP was canceled |  
| 400 | 2025 | otp_expired | The OTP has expired |  
| 400 | 2026 | otp_failed | The OTP has failed, maximum attempts reached |  
| 400 | 2027 | otp_failed | Max attempts reached |  
| 400 | 2028 | otp_expired | The PIN has expired |  
| 400 | 2029 | invalid_pin | The PIN provided does not verify |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.verify_otp(otp_id, verify_pin_request, async_req=True)
        >>> result = thread.get()

        Args:
            otp_id (str): Identifier of the OTP request
            pin (str, int): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            VerifyPinResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['otp_id'] = \
            otp_id
        kwargs['verify_pin_request'] = VerifyPinRequest(pin)
        return self.verify_otp_endpoint.call_with_http_info(**kwargs)




import sys
import unittest

import smscx_client
from smscx_client.model.reports_summary_delivery_response_data_value import ReportsSummaryDeliveryResponseDataValue
globals()['ReportsSummaryDeliveryResponseDataValue'] = ReportsSummaryDeliveryResponseDataValue
from smscx_client.model.reports_summary_delivery_response import ReportsSummaryDeliveryResponse


class TestReportsSummaryDeliveryResponse(unittest.TestCase):
    """ReportsSummaryDeliveryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportsSummaryDeliveryResponse(self):
        """Test ReportsSummaryDeliveryResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ReportsSummaryDeliveryResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.info_delete_group import InfoDeleteGroup
globals()['InfoDeleteGroup'] = InfoDeleteGroup
from smscx_client.model.delete_group import DeleteGroup


class TestDeleteGroup(unittest.TestCase):
    """DeleteGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDeleteGroup(self):
        """Test DeleteGroup"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DeleteGroup()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import unittest

import smscx_client
from smscx_client.api.multichannel_api import MultichannelApi  # noqa: E501


class TestMultichannelApi(unittest.TestCase):
    """MultichannelApi unit test stubs"""

    def setUp(self):
        self.api = MultichannelApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_scheduled_multichannel_campaign(self):
        """Test case for delete_scheduled_multichannel_campaign

        Delete scheduled Multichannel campaign  # noqa: E501
        """
        pass

    def test_delete_scheduled_multichannel_message(self):
        """Test case for delete_scheduled_multichannel_message

        Delete scheduled Multichannel message  # noqa: E501
        """
        pass

    def test_estimate_multichannel_campaign(self):
        """Test case for estimate_multichannel_campaign

        Estimate Multichannel campaign  # noqa: E501
        """
        pass

    def test_estimate_multichannel_message(self):
        """Test case for estimate_multichannel_message

        Estimate Multichannel message  # noqa: E501
        """
        pass

    def test_send_multichannel_campaign(self):
        """Test case for send_multichannel_campaign

        Send Multichannel campaign  # noqa: E501
        """
        pass

    def test_send_multichannel_message(self):
        """Test case for send_multichannel_message

        Send Multichannel message  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    ApiModel
)
from smscx_client.exceptions import ApiAttributeError


def lazy_import():
    from smscx_client.model.custom_fields import CustomFields
    globals()['CustomFields'] = CustomFields


class SendWhatsappMessageRequestEstimate(ModelNormal):


    allowed_values = {
    }

    validations = {
        ('_from',): {
            'max_length': 15,
            'min_length': 3,
        },
        ('country_iso',): {
            'max_length': 2,
            'min_length': 2,
        },
        ('track_data',): {
            'max_length': 36,
            'min_length': 36,
            'regex': {
                'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
            },
        },
    }

    @cached_property
    def additional_properties_type():
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def api_types():
        """
        Returns
            api_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'to': ([str],),  # noqa: E501
            '_from': (str,),  # noqa: E501
            'template_id': (int,),  # noqa: E501
            'custom_fields': (CustomFields,),  # noqa: E501
            'country_iso': (str,),  # noqa: E501
            'allow_invalid': (bool,),  # noqa: E501
            'scheduled_date': (datetime,),  # noqa: E501
            'is_utc': (bool,),  # noqa: E501
            'dlr_callback_url': (str,),  # noqa: E501
            'track_data': (str,),  # noqa: E501
            'short_response': (bool,),  # noqa: E501
            'no_text_details': (bool,),  # noqa: E501
            'show_timezone': (bool,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'to': 'to',  # noqa: E501
        '_from': 'from',  # noqa: E501
        'template_id': 'templateId',  # noqa: E501
        'custom_fields': 'customFields',  # noqa: E501
        'country_iso': 'countryIso',  # noqa: E501
        'allow_invalid': 'allowInvalid',  # noqa: E501
        'scheduled_date': 'scheduledDate',  # noqa: E501
        'is_utc': 'isUtc',  # noqa: E501
        'dlr_callback_url': 'dlrCallbackUrl',  # noqa: E501
        'track_data': 'trackData',  # noqa: E501
        'short_response': 'shortResponse',  # noqa: E501
        'no_text_details': 'noTextDetails',  # noqa: E501
        'show_timezone': 'showTimezone',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_api_data(cls, to, _from, template_id, *args, **kwargs):  # noqa: E501
        """SendWhatsappMessageRequestEstimate - a model

        Args:
            to ([str]): A string with single phone number or an array of phone numbers in international E.164 format or national format. If national format is provided, for better validation you must use the parameter `countryIso` to provide the country code of the destination phone number.
            _from (str): The originator (sender name) of the text message (min 3, max 15 characters). If the originator used in this value is not approved, it will be overwritten by a default system originator (eg. InfoText). Read more about [sender names](#)
            template_id (int): Identifier of the approved Viber template


            custom_fields (CustomFields): [optional]  # noqa: E501
            country_iso (str): Country ISO (two-letter) of the destination phone numbers (if provided in national format). Please note that if an international E.164 phone number format is provided in the `to` parameter, the **countryIso** will be ignored. Eg. **FR** for France, **GB** for United Kingdom. Note: It is \"GB\", not \"UK\", as per the ISO-3166 alpha 2.. [optional]  # noqa: E501
            allow_invalid (bool): By default an error will be thrown if any invalid numbers are detected in the `to` parameter. Set this parameter to `true` if you want to process the request even if invalid numbers are detected. The response will contain in the `info` object the property `invalid`, wich is an array with the detected invalid phone numbers. [optional] if omitted the server will use the default value of False  # noqa: E501
            scheduled_date (datetime): If you want to schedule the Whatsapp message at a later date. The date provided must be in format **YYYY-MM-DD HH:MM:SS** (Eg. 2021-06-23 14:26:10). By default, the date and time in this parameter is treated as `UTC`. So if you want to schedule a Whatsapp message to a french phone number at 16:00 (France is UTC+2), then you should set the parameter at 2021-06-23 14:00 (UTC). If you don't want to make the calculations, you can set this parameter as the date time of the destination (eg. 2021-06-23 16:00) and set the parameter `isUtc` to `false`. In this way, the API will automatically make the conversion from the destination timezone to UTC and set the scheduledDate accordingly. [optional]  # noqa: E501
            is_utc (bool): If set to `false` it will indicate that the `scheduledDate` parameter is not a date in UTC time, but the date relative to the timezone of the destination phone number. The API will calculate the offset and convert the date to UTC.  . [optional] if omitted the server will use the default value of True  # noqa: E501
            dlr_callback_url (str): A valid URL to receive the delivery report update for the sent Whatsapp message. If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
            track_data (str): Allows to track messages a client provided ID. The `trackData` value will be passed back with the response and in all callbacks (webhooks). If the value is not a valid UUID (v1-v5) the API will not return an error but will discard this parameter. [optional]  # noqa: E501
            short_response (bool): If set to `true`, it will return the full `info` object and empty `data` object. For situations when you don't need the information in the `data` object and want to save bandwith. [optional] if omitted the server will use the default value of False  # noqa: E501
            no_text_details (bool): The response will not have the parameters `data.text` and `data.textAnalysis`. For situations when you send to large lists of phone numbers and don't need all response parameters (save bandwith). [optional] if omitted the server will use the default value of False  # noqa: E501
            show_timezone (bool): Shows the parameter `timezone` in the response, for each phone number. [optional] if omitted the server will use the default value of False  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(ApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.to = to
        self._from = _from
        self.template_id = template_id
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, to, _from, template_id, *args, **kwargs):  # noqa: E501
        """SendWhatsappMessageRequestEstimate - a model

        Args:
            to ([str]): A string with single phone number or an array of phone numbers in international E.164 format or national format. If national format is provided, for better validation you must use the parameter `countryIso` to provide the country code of the destination phone number.
            _from (str): The originator (sender name) of the text message (min 3, max 15 characters). If the originator used in this value is not approved, it will be overwritten by a default system originator (eg. InfoText). Read more about [sender names](#)
            template_id (int): Identifier of the approved Viber template


            custom_fields (CustomFields): [optional]  # noqa: E501
            country_iso (str): Country ISO (two-letter) of the destination phone numbers (if provided in national format). Please note that if an international E.164 phone number format is provided in the `to` parameter, the **countryIso** will be ignored. Eg. **FR** for France, **GB** for United Kingdom. Note: It is \"GB\", not \"UK\", as per the ISO-3166 alpha 2.. [optional]  # noqa: E501
            allow_invalid (bool): By default an error will be thrown if any invalid numbers are detected in the `to` parameter. Set this parameter to `true` if you want to process the request even if invalid numbers are detected. The response will contain in the `info` object the property `invalid`, wich is an array with the detected invalid phone numbers. [optional] if omitted the server will use the default value of False  # noqa: E501
            scheduled_date (datetime): If you want to schedule the Whatsapp message at a later date. The date provided must be in format **YYYY-MM-DD HH:MM:SS** (Eg. 2021-06-23 14:26:10). By default, the date and time in this parameter is treated as `UTC`. So if you want to schedule a Whatsapp message to a french phone number at 16:00 (France is UTC+2), then you should set the parameter at 2021-06-23 14:00 (UTC). If you don't want to make the calculations, you can set this parameter as the date time of the destination (eg. 2021-06-23 16:00) and set the parameter `isUtc` to `false`. In this way, the API will automatically make the conversion from the destination timezone to UTC and set the scheduledDate accordingly. [optional]  # noqa: E501
            is_utc (bool): If set to `false` it will indicate that the `scheduledDate` parameter is not a date in UTC time, but the date relative to the timezone of the destination phone number. The API will calculate the offset and convert the date to UTC.  . [optional] if omitted the server will use the default value of True  # noqa: E501
            dlr_callback_url (str): A valid URL to receive the delivery report update for the sent Whatsapp message. If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
            track_data (str): Allows to track messages a client provided ID. The `trackData` value will be passed back with the response and in all callbacks (webhooks). If the value is not a valid UUID (v1-v5) the API will not return an error but will discard this parameter. [optional]  # noqa: E501
            short_response (bool): If set to `true`, it will return the full `info` object and empty `data` object. For situations when you don't need the information in the `data` object and want to save bandwith. [optional] if omitted the server will use the default value of False  # noqa: E501
            no_text_details (bool): The response will not have the parameters `data.text` and `data.textAnalysis`. For situations when you send to large lists of phone numbers and don't need all response parameters (save bandwith). [optional] if omitted the server will use the default value of False  # noqa: E501
            show_timezone (bool): Shows the parameter `timezone` in the response, for each phone number. [optional] if omitted the server will use the default value of False  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.to = to
        self._from = _from
        self.template_id = template_id
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_api_data` to instantiate "
                                     f"class with read only attributes.")



import sys
import unittest

import smscx_client
from smscx_client.model.rich_media import RichMedia
globals()['RichMedia'] = RichMedia
from smscx_client.model.templates_update_request import TemplatesUpdateRequest


class TestTemplatesUpdateRequest(unittest.TestCase):
    """TemplatesUpdateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTemplatesUpdateRequest(self):
        """Test TemplatesUpdateRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TemplatesUpdateRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages  # noqa: H301

NAME = "smscx_client"
VERSION = "0.1.9"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
  "urllib3 >= 1.25.3",
  "python-dateutil",
]

setup(
    name=NAME,
    version=VERSION,
    description="SMS API",
    author="SMS Connexion",
    author_email="dev@sms.cx",
    url="",
    project_urls = {
      'Homepage': 'https://sms.cx',
      'Github': 'https://github.com/smscx/smscx-api-python-library'
    },
    keywords=["SMS", "SMS API", "BULK SMS", "VALIDATE PHONE NUMBERS", "RENT PHONE NUMBERS"],
    python_requires=">=3.6",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache-2.0",
)



import sys
import unittest

import smscx_client
from smscx_client.model.add_contacts_to_group_request import AddContactsToGroupRequest
from smscx_client.model.add_contacts_to_group_with_fields_request import AddContactsToGroupWithFieldsRequest
from smscx_client.model.group_add import GroupAdd
globals()['AddContactsToGroupRequest'] = AddContactsToGroupRequest
globals()['AddContactsToGroupWithFieldsRequest'] = AddContactsToGroupWithFieldsRequest
globals()['GroupAdd'] = GroupAdd


class TestAddContactsToGroupRequest(unittest.TestCase):
    """AddContactsToGroupRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAddContactsToGroupRequest(self):
        """Test AddContactsToGroupRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AddContactsToGroupRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_number_lookup import DataNumberLookup
from smscx_client.model.info_numbers_lookup import InfoNumbersLookup
globals()['DataNumberLookup'] = DataNumberLookup
globals()['InfoNumbersLookup'] = InfoNumbersLookup
from smscx_client.model.numbers_bulk_lookup_result import NumbersBulkLookupResult


class TestNumbersBulkLookupResult(unittest.TestCase):
    """NumbersBulkLookupResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNumbersBulkLookupResult(self):
        """Test NumbersBulkLookupResult"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NumbersBulkLookupResult()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.custom_fields import CustomFields
globals()['CustomFields'] = CustomFields
from smscx_client.model.send_whatsapp_message_request_estimate import SendWhatsappMessageRequestEstimate


class TestSendWhatsappMessageRequestEstimate(unittest.TestCase):
    """SendWhatsappMessageRequestEstimate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSendWhatsappMessageRequestEstimate(self):
        """Test SendWhatsappMessageRequestEstimate"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SendWhatsappMessageRequestEstimate()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_number_validate import DataNumberValidate


class TestDataNumberValidate(unittest.TestCase):
    """DataNumberValidate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDataNumberValidate(self):
        """Test DataNumberValidate"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DataNumberValidate()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.info_shortlink_new import InfoShortlinkNew
globals()['InfoShortlinkNew'] = InfoShortlinkNew
from smscx_client.model.shortlink_new_response import ShortlinkNewResponse


class TestShortlinkNewResponse(unittest.TestCase):
    """ShortlinkNewResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testShortlinkNewResponse(self):
        """Test ShortlinkNewResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ShortlinkNewResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    ApiModel
)
from smscx_client.exceptions import ApiAttributeError


def lazy_import():
    from smscx_client.model.transliteration import Transliteration
    globals()['Transliteration'] = Transliteration


class SendSmsCampaignRequest(ModelNormal):


    allowed_values = {
    }

    validations = {
        ('_from',): {
            'max_length': 15,
            'min_length': 3,
        },
        ('idempotency_id',): {
            'max_length': 36,
            'min_length': 36,
            'regex': {
                'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
            },
        },
    }

    @cached_property
    def additional_properties_type():
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def api_types():
        """
        Returns
            api_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'groups': ([int],),  # noqa: E501
            '_from': (str,),  # noqa: E501
            'text': (str,),  # noqa: E501
            'scheduled_date': (datetime,),  # noqa: E501
            'is_utc': (bool,),  # noqa: E501
            'dlr_callback_url': (str,),  # noqa: E501
            'short_response': (bool,),  # noqa: E501
            'no_text_details': (bool,),  # noqa: E501
            'show_timezone': (bool,),  # noqa: E501
            'idempotency_id': (str,),  # noqa: E501
            'transliteration': (Transliteration,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'groups': 'groups',  # noqa: E501
        '_from': 'from',  # noqa: E501
        'text': 'text',  # noqa: E501
        'scheduled_date': 'scheduledDate',  # noqa: E501
        'is_utc': 'isUtc',  # noqa: E501
        'dlr_callback_url': 'dlrCallbackUrl',  # noqa: E501
        'short_response': 'shortResponse',  # noqa: E501
        'no_text_details': 'noTextDetails',  # noqa: E501
        'show_timezone': 'showTimezone',  # noqa: E501
        'idempotency_id': 'idempotencyId',  # noqa: E501
        'transliteration': 'transliteration',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_api_data(cls, groups, _from, text, *args, **kwargs):  # noqa: E501
        """SendSmsCampaignRequest - a model

        Args:
            groups ([int]): An array of identifiers for groups of contacts
            _from (str): The originator (sender name) of the text message (min 3, max 15 characters). If the originator used in this value is not approved, it will be overwritten by a default system originator (eg. InfoText). Read more about [sender names](#)
            text (str): A standard GSM message is limited to 160 characters. If a text message contains even one (or more) Unicode characters (for example ç, ö, ü) the character limit then becomes 70 characters per message part. Long text messages are concatenated into a multipart SMS. A text message can have up to 1530 characters (10 message parts).   <br><br>   You can use custom fields in the text, by using the name of the field between two curly braces. The placeholders will be replaced with the availale data. If no data is found the placeholder will be replaced by a blank string. Available fields are:   - `{{firstName}}` - will be replaced with data saved when the contact was added to group  - `{{lastName}}` - will be replaced with data saved when the contact was added to group  - `{{email}}` - will be replaced with data saved when the contact was added to group  - `{{field1}}` - `{{field5}}` - will be replaced with data saved when the contact was added to group<br>   - `{{<CUSTOM-FIELD>}}` - Eg. **{{height}}** cand be used as placeholder if this custom field was added when [validating the contact to a group](#add-contacts-to-a-group)   - `{{optoutLink}}`  - `{{shortlink:<ID>}}`  - `{{attachement:<ID>}}`  <br> <br>   The placeholder `{{shortlink:<ID>}}` is used when you want to track a shortlink. The API will generate a unique string for every contact, and doing so you will know what phone number clicked on the link. Eg. `{{shortlink:bVc}}` will be replaced by **ht<span>tps://</span>en.ax/bVc/r2N**  <br><br>  General placeholders can be used in the text, which will be replaced with data. Available general placeholders are:   - `{{numbers}}` - will be replaced with a random number. Default length of the number is 4 characters. Eg. **9765**  - `{{numbers:8}}` - will be replaced with a random number with length of 8 characters. The minimum number length can be 1 and maximum length can be 20  - `{{letters}}` - will be replaced with a random string of letters. Default length of the string is 4 characters. Eg. **AJKV**  - `{{letters:10}}` - will be replaced with a random string with length of 10 characters. The minimum string length can be 1 and maximum length can be 20  - `{{alphanumeric}}` - will be replaced with a random string of letters and numbers. Default length of the string is 4 characters. Eg. **BH4V**  - `{{alphanumeric:6}}` - will be replaced with a random string of letters and numbers with length of 6 characters. The minimum alphanumeric string length can be 1 and maximum length can be 20  - `{{today}}` - will be replaced with today date in following example format: **7 Aug 2022**


            scheduled_date (datetime): If you want to schedule the SMS at a later date. The date provided must be in format **YYYY-MM-DD HH:MM:SS** (Eg. 2021-06-23 14:26:10). By default, the date and time in this parameter is treated as `UTC`. So if you want to schedule a SMS to a french phone number at 16:00 (France is UTC+2), then you should set the parameter at 2021-06-23 14:00 (UTC). If you don't want to make the calculations, you can set this parameter as the date time of the destination (eg. 2021-06-23 16:00) and set the parameter `isUtc` to `false`. In this way, the API will automatically make the conversion from the destination timezone to UTC and set the scheduledDate accordingly. [optional]  # noqa: E501
            is_utc (bool): If set to `false` it will indicate that the `scheduledDate` parameter is not a date in UTC time, but the date relative to the timezone of the destination phone number. The API will calculate the offset and convert the date to UTC.  . [optional] if omitted the server will use the default value of True  # noqa: E501
            dlr_callback_url (str): A valid URL to receive the delivery report update for the sent SMS. If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
            short_response (bool): If set to `true`, it will return the full `info` object and empty `data` object. For situations when you don't need the information in the `data` object and want to save bandwith. [optional] if omitted the server will use the default value of False  # noqa: E501
            no_text_details (bool): The response will not have the parameters `data.text` and `data.textAnalysis`. For situations when you send to large lists of phone numbers and don't need all response parameters (save bandwith). [optional] if omitted the server will use the default value of False  # noqa: E501
            show_timezone (bool): Shows the parameter `timezone` in the response, for each phone number. [optional] if omitted the server will use the default value of False  # noqa: E501
            idempotency_id (str): A unique idempotency id generated by the client. For more information, refer to [Idempotent requests](#). The API will return an error if the value provided is not a valid UUID (v1-v5). [optional]  # noqa: E501
            transliteration (Transliteration): [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(ApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.groups = groups
        self._from = _from
        self.text = text
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, groups, _from, text, *args, **kwargs):  # noqa: E501
        """SendSmsCampaignRequest - a model

        Args:
            groups ([int]): An array of identifiers for groups of contacts
            _from (str): The originator (sender name) of the text message (min 3, max 15 characters). If the originator used in this value is not approved, it will be overwritten by a default system originator (eg. InfoText). Read more about [sender names](#)
            text (str): A standard GSM message is limited to 160 characters. If a text message contains even one (or more) Unicode characters (for example ç, ö, ü) the character limit then becomes 70 characters per message part. Long text messages are concatenated into a multipart SMS. A text message can have up to 1530 characters (10 message parts).   <br><br>   You can use custom fields in the text, by using the name of the field between two curly braces. The placeholders will be replaced with the availale data. If no data is found the placeholder will be replaced by a blank string. Available fields are:   - `{{firstName}}` - will be replaced with data saved when the contact was added to group  - `{{lastName}}` - will be replaced with data saved when the contact was added to group  - `{{email}}` - will be replaced with data saved when the contact was added to group  - `{{field1}}` - `{{field5}}` - will be replaced with data saved when the contact was added to group<br>   - `{{<CUSTOM-FIELD>}}` - Eg. **{{height}}** cand be used as placeholder if this custom field was added when [validating the contact to a group](#add-contacts-to-a-group)   - `{{optoutLink}}`  - `{{shortlink:<ID>}}`  - `{{attachement:<ID>}}`  <br> <br>   The placeholder `{{shortlink:<ID>}}` is used when you want to track a shortlink. The API will generate a unique string for every contact, and doing so you will know what phone number clicked on the link. Eg. `{{shortlink:bVc}}` will be replaced by **ht<span>tps://</span>en.ax/bVc/r2N**  <br><br>  General placeholders can be used in the text, which will be replaced with data. Available general placeholders are:   - `{{numbers}}` - will be replaced with a random number. Default length of the number is 4 characters. Eg. **9765**  - `{{numbers:8}}` - will be replaced with a random number with length of 8 characters. The minimum number length can be 1 and maximum length can be 20  - `{{letters}}` - will be replaced with a random string of letters. Default length of the string is 4 characters. Eg. **AJKV**  - `{{letters:10}}` - will be replaced with a random string with length of 10 characters. The minimum string length can be 1 and maximum length can be 20  - `{{alphanumeric}}` - will be replaced with a random string of letters and numbers. Default length of the string is 4 characters. Eg. **BH4V**  - `{{alphanumeric:6}}` - will be replaced with a random string of letters and numbers with length of 6 characters. The minimum alphanumeric string length can be 1 and maximum length can be 20  - `{{today}}` - will be replaced with today date in following example format: **7 Aug 2022**


            scheduled_date (datetime): If you want to schedule the SMS at a later date. The date provided must be in format **YYYY-MM-DD HH:MM:SS** (Eg. 2021-06-23 14:26:10). By default, the date and time in this parameter is treated as `UTC`. So if you want to schedule a SMS to a french phone number at 16:00 (France is UTC+2), then you should set the parameter at 2021-06-23 14:00 (UTC). If you don't want to make the calculations, you can set this parameter as the date time of the destination (eg. 2021-06-23 16:00) and set the parameter `isUtc` to `false`. In this way, the API will automatically make the conversion from the destination timezone to UTC and set the scheduledDate accordingly. [optional]  # noqa: E501
            is_utc (bool): If set to `false` it will indicate that the `scheduledDate` parameter is not a date in UTC time, but the date relative to the timezone of the destination phone number. The API will calculate the offset and convert the date to UTC.  . [optional] if omitted the server will use the default value of True  # noqa: E501
            dlr_callback_url (str): A valid URL to receive the delivery report update for the sent SMS. If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
            short_response (bool): If set to `true`, it will return the full `info` object and empty `data` object. For situations when you don't need the information in the `data` object and want to save bandwith. [optional] if omitted the server will use the default value of False  # noqa: E501
            no_text_details (bool): The response will not have the parameters `data.text` and `data.textAnalysis`. For situations when you send to large lists of phone numbers and don't need all response parameters (save bandwith). [optional] if omitted the server will use the default value of False  # noqa: E501
            show_timezone (bool): Shows the parameter `timezone` in the response, for each phone number. [optional] if omitted the server will use the default value of False  # noqa: E501
            idempotency_id (str): A unique idempotency id generated by the client. For more information, refer to [Idempotent requests](#). The API will return an error if the value provided is not a valid UUID (v1-v5). [optional]  # noqa: E501
            transliteration (Transliteration): [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.groups = groups
        self._from = _from
        self.text = text
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_api_data` to instantiate "
                                     f"class with read only attributes.")



import sys
import unittest

import smscx_client
from smscx_client.model.info_template_update import InfoTemplateUpdate
globals()['InfoTemplateUpdate'] = InfoTemplateUpdate
from smscx_client.model.templates_delete_response import TemplatesDeleteResponse


class TestTemplatesDeleteResponse(unittest.TestCase):
    """TemplatesDeleteResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTemplatesDeleteResponse(self):
        """Test TemplatesDeleteResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TemplatesDeleteResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    ApiModel
)
from smscx_client.exceptions import ApiAttributeError


def lazy_import():
    from smscx_client.model.reports_summary_delivery_response_data_value import ReportsSummaryDeliveryResponseDataValue
    globals()['ReportsSummaryDeliveryResponseDataValue'] = ReportsSummaryDeliveryResponseDataValue


class ReportsSummaryDeliveryResponse(ModelNormal):


    allowed_values = {
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def api_types():
        """
        Returns
            api_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'data': ({str: (ReportsSummaryDeliveryResponseDataValue,)},),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'data': 'data',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_api_data(cls, data, *args, **kwargs):  # noqa: E501
        """ReportsSummaryDeliveryResponse - a model

        Args:
            data ({str: (ReportsSummaryDeliveryResponseDataValue,)}):


        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(ApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.data = data
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, data, *args, **kwargs):  # noqa: E501
        """ReportsSummaryDeliveryResponse - a model

        Args:
            data ({str: (ReportsSummaryDeliveryResponseDataValue,)}):


        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.data = data
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_api_data` to instantiate "
                                     f"class with read only attributes.")



import unittest

import smscx_client
from smscx_client.api.oauth_api import OauthApi  # noqa: E501


class TestOauthApi(unittest.TestCase):
    """OauthApi unit test stubs"""

    def setUp(self):
        self.api = OauthApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_access_token(self):
        """Test case for get_access_token

        Get access token  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.api_client import ApiClient, Endpoint as _Endpoint
from smscx_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from smscx_client.model.model400_invalid_param import Model400InvalidParam
from smscx_client.model.model401_unauthorized import Model401Unauthorized
from smscx_client.model.model403_insufficient_scope import Model403InsufficientScope
from smscx_client.model.model404_not_found import Model404NotFound
from smscx_client.model.model500_server_error import Model500ServerError
from smscx_client.model.shortlink_delete_response import ShortlinkDeleteResponse
from smscx_client.model.shortlink_details_response import ShortlinkDetailsResponse
from smscx_client.model.shortlink_new_request import ShortlinkNewRequest
from smscx_client.model.shortlink_new_response import ShortlinkNewResponse
from smscx_client.model.shortlink_update_request import ShortlinkUpdateRequest
from smscx_client.model.shortlink_update_response import ShortlinkUpdateResponse
from smscx_client.model.shortlinks_list_response import ShortlinksListResponse


class ShortlinksApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_shortlink_endpoint = _Endpoint(
            settings={
                'response_type': (ShortlinkNewResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/shortlinks',
                'operation_id': 'create_shortlink',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'shortlink_new_request',
                ],
                'required': [
                    'shortlink_new_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'shortlink_new_request':
                        (ShortlinkNewRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'shortlink_new_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.delete_shortlink_endpoint = _Endpoint(
            settings={
                'response_type': (ShortlinkDeleteResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/shortlinks/{shortId}',
                'operation_id': 'delete_shortlink',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'short_id',
                ],
                'required': [
                    'short_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'short_id':
                        (str,),
                },
                'attribute_map': {
                    'short_id': 'shortId',
                },
                'location_map': {
                    'short_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.export_shortlink_hits_to_csv_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/shortlinks/{shortId}/csv',
                'operation_id': 'export_shortlink_hits_to_csv',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'short_id',
                ],
                'required': [
                    'short_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'short_id':
                        (str,),
                },
                'attribute_map': {
                    'short_id': 'shortId',
                },
                'location_map': {
                    'short_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/csv',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.export_shortlink_hits_to_xlsx_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/shortlinks/{shortId}/xlsx',
                'operation_id': 'export_shortlink_hits_to_xlsx',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'short_id',
                ],
                'required': [
                    'short_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'short_id':
                        (str,),
                },
                'attribute_map': {
                    'short_id': 'shortId',
                },
                'location_map': {
                    'short_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_shortlink_hits_endpoint = _Endpoint(
            settings={
                'response_type': (ShortlinkDetailsResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/shortlinks/{shortId}',
                'operation_id': 'get_shortlink_hits',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'short_id',
                    'short_response',
                    'limit',
                    'next',
                    'previous',
                ],
                'required': [
                    'short_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'short_id':
                        (str,),
                    'short_response':
                        (bool,),
                    'limit':
                        (int,),
                    'next':
                        (str,),
                    'previous':
                        (str,),
                },
                'attribute_map': {
                    'short_id': 'shortId',
                    'short_response': 'short_response',
                    'limit': 'limit',
                    'next': 'next',
                    'previous': 'previous',
                },
                'location_map': {
                    'short_id': 'path',
                    'short_response': 'query',
                    'limit': 'query',
                    'next': 'query',
                    'previous': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_shortlinks_list_endpoint = _Endpoint(
            settings={
                'response_type': (ShortlinksListResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/shortlinks',
                'operation_id': 'get_shortlinks_list',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_shortlink_endpoint = _Endpoint(
            settings={
                'response_type': (ShortlinkUpdateResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/shortlinks/{shortId}',
                'operation_id': 'update_shortlink',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'short_id',
                    'shortlink_update_request',
                ],
                'required': [
                    'short_id',
                    'shortlink_update_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'short_id':
                        (str,),
                    'shortlink_update_request':
                        (ShortlinkUpdateRequest,),
                },
                'attribute_map': {
                    'short_id': 'shortId',
                },
                'location_map': {
                    'short_id': 'path',
                    'shortlink_update_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def create_shortlink(
        self,
        shortlink_new_request,
        **kwargs
    ):
        """Create shortlink  # noqa: E501

        Creates a new shortlink.    
### Errors for POST `/shortlinks`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1401  |  invalid_param  |  The URL is empty or parameter `url` not set |  

|  400 | 1402  |  invalid_param  |  The URL provided is invalid |  

|  400 | 1404  |  invalid_param  |  The parameter `name` is invalid (min 3, max 25 characters) |  

|  400 | 1405  |  duplicate_id  |  Short ID already exists |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_shortlink(shortlink_new_request, async_req=True)
        >>> result = thread.get()

        Args:
            shortlink_new_request (ShortlinkNewRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ShortlinkNewResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['shortlink_new_request'] = \
            shortlink_new_request
        return self.create_shortlink_endpoint.call_with_http_info(**kwargs)

    def delete_shortlink(
        self,
        short_id,
        **kwargs
    ):
        """Delete shortlink  # noqa: E501

        Deletes a shortlink and all the hits data associated, if a valid identifier was provided.    
### Errors for DELETE `/shortlinks/{shortId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1400  |  not_found  |  Shortlink ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_shortlink(short_id, async_req=True)
        >>> result = thread.get()

        Args:
            short_id (str): Identifier of the shortlink

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ShortlinkDeleteResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['short_id'] = \
            short_id
        return self.delete_shortlink_endpoint.call_with_http_info(**kwargs)

    def export_shortlink_hits_to_csv(
        self,
        short_id,
        **kwargs
    ):
        """Export shortlink hits to CSV  # noqa: E501

        Exports the hits details of a shortlink (phone number, device, model, operating system, browser, city, country, etc.) to a CSV file.    If there are no hits for the shortlink, an empty CSV file is returned (with first line headers).    
### Errors for GET `/shortlinks/{shortId}/csv`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1400  |  not_found  |  Shortlink ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.export_shortlink_hits_to_csv(short_id, async_req=True)
        >>> result = thread.get()

        Args:
            short_id (str): Identifier of the shortlink

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['short_id'] = \
            short_id
        return self.export_shortlink_hits_to_csv_endpoint.call_with_http_info(**kwargs)

    def export_shortlink_hits_to_xlsx(
        self,
        short_id,
        **kwargs
    ):
        """Export shortlink hits to XLSX  # noqa: E501

        Exports the hits details of a shortlink (phone number, device, model, operating system, browser, city, country, etc.) to a XLSX file (Excel).    If there are no hits for the shortlink, an empty XLSX file is returned (with first line headers).    
### Errors for GET `/shortlinks/{shortId}/xlsx`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1400  |  not_found  |  Shortlink ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.export_shortlink_hits_to_xlsx(short_id, async_req=True)
        >>> result = thread.get()

        Args:
            short_id (str): Identifier of the shortlink

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['short_id'] = \
            short_id
        return self.export_shortlink_hits_to_xlsx_endpoint.call_with_http_info(**kwargs)

    def get_shortlink_hits(
        self,
        short_id,
        **kwargs
    ):
        """Get shortlink hits  # noqa: E501

        Retrieves the hits details (phone number, device, model, operating system, browser, city, country, etc.) of a shortlink if a valid identifier was provided.    
### Errors for GET `/shortlinks/{shortId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1400  |  not_found  |  Shortlink ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_shortlink_hits(short_id, async_req=True)
        >>> result = thread.get()

        Args:
            short_id (str): Identifier of the shortlink

        Keyword Args:
            short_response (bool): If set to true, it will return the full `info` object and an empty `data` object. [optional] if omitted the server will use the default value of False
            limit (int): A limit on the number of objects to be returned. [optional] if omitted the server will use the default value of 500
            next (str): The next token used to retrieve additional data. [optional]
            previous (str): The previous token used to retrieve additional data. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ShortlinkDetailsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['short_id'] = \
            short_id
        return self.get_shortlink_hits_endpoint.call_with_http_info(**kwargs)

    def get_shortlinks_list(
        self,
        **kwargs
    ):
        """Get shortlinks list  # noqa: E501

        Retrieves the list of existing shortlinks. The shortlinks are returned sorted by creation date, with the most recent shortlink appearing first.    If no shortlinks are available, an empty data object is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_shortlinks_list(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ShortlinksListResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_shortlinks_list_endpoint.call_with_http_info(**kwargs)

    def update_shortlink(
        self,
        short_id,
        shortlink_update_request,
        **kwargs
    ):
        """Update shortlink  # noqa: E501

        Updates the specified shortlink by setting the values of the parameters passed. Any parameters not provided will be left unchanged.    Returns HTTP `204 No content` if the parameters provided did not update the contact because the data was already the same.    
### Errors for PATCH `/shortlinks/{shortId} `  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1400  |  not_found  |  Shortlink ID not found |  

|  400 | 1401  |  invalid_param  |  The URL is empty or parameter `url` not set |  

|  400 | 1402  |  invalid_param  |  The URL provided is invalid |  

|  400 | 1404  |  invalid_param  |  The parameter `name` is invalid (min 3, max 25 characters) |  

|  400 | 1406  |  invalid_param  |  At least one parameter required (name, url) |  

|  400 | 1407  |  duplicate_value  |  You already have a shortlink with this name |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_shortlink(short_id, shortlink_update_request, async_req=True)
        >>> result = thread.get()

        Args:
            short_id (str): Identifier of the shortlink
            shortlink_update_request (ShortlinkUpdateRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ShortlinkUpdateResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['short_id'] = \
            short_id
        kwargs['shortlink_update_request'] = \
            shortlink_update_request
        return self.update_shortlink_endpoint.call_with_http_info(**kwargs)




import sys
import unittest

import smscx_client
from smscx_client.model.data_reports_campaigns import DataReportsCampaigns
from smscx_client.model.info_reports_campaigns import InfoReportsCampaigns
from smscx_client.model.paging import Paging
globals()['DataReportsCampaigns'] = DataReportsCampaigns
globals()['InfoReportsCampaigns'] = InfoReportsCampaigns
globals()['Paging'] = Paging
from smscx_client.model.reports_campaigns_respone import ReportsCampaignsRespone


class TestReportsCampaignsRespone(unittest.TestCase):
    """ReportsCampaignsRespone unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportsCampaignsRespone(self):
        """Test ReportsCampaignsRespone"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ReportsCampaignsRespone()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_conversations import DataConversations
globals()['DataConversations'] = DataConversations
from smscx_client.model.conversations_list_response import ConversationsListResponse


class TestConversationsListResponse(unittest.TestCase):
    """ConversationsListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testConversationsListResponse(self):
        """Test ConversationsListResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ConversationsListResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.info_group import InfoGroup
globals()['InfoGroup'] = InfoGroup
from smscx_client.model.group_response import GroupResponse


class TestGroupResponse(unittest.TestCase):
    """GroupResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGroupResponse(self):
        """Test GroupResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GroupResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_number_lookup_webhook import DataNumberLookupWebhook
globals()['DataNumberLookupWebhook'] = DataNumberLookupWebhook
from smscx_client.model.call_back_request_number_lookup import CallBackRequestNumberLookup


class TestCallBackRequestNumberLookup(unittest.TestCase):
    """CallBackRequestNumberLookup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCallBackRequestNumberLookup(self):
        """Test CallBackRequestNumberLookup"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CallBackRequestNumberLookup()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.reports_summary_channel_response_data_value import ReportsSummaryChannelResponseDataValue
globals()['ReportsSummaryChannelResponseDataValue'] = ReportsSummaryChannelResponseDataValue
from smscx_client.model.reports_summary_channel_response import ReportsSummaryChannelResponse


class TestReportsSummaryChannelResponse(unittest.TestCase):
    """ReportsSummaryChannelResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportsSummaryChannelResponse(self):
        """Test ReportsSummaryChannelResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ReportsSummaryChannelResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.text_analysis import TextAnalysis
globals()['TextAnalysis'] = TextAnalysis
from smscx_client.model.data_conversation_reply import DataConversationReply


class TestDataConversationReply(unittest.TestCase):
    """DataConversationReply unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDataConversationReply(self):
        """Test DataConversationReply"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DataConversationReply()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import unittest

import smscx_client
from smscx_client.api.otp_api import OtpApi  # noqa: E501


class TestOtpApi(unittest.TestCase):
    """OtpApi unit test stubs"""

    def setUp(self):
        self.api = OtpApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_otp(self):
        """Test case for cancel_otp

        Cancel OTP  # noqa: E501
        """
        pass

    def test_get_otp_status(self):
        """Test case for get_otp_status

        Get OTP status  # noqa: E501
        """
        pass

    def test_new_otp(self):
        """Test case for new_otp

        New OTP  # noqa: E501
        """
        pass

    def test_verify_otp(self):
        """Test case for verify_otp

        Verify OTP  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.text import Text
globals()['Text'] = Text
from smscx_client.model.transliteration_analysis import TransliterationAnalysis


class TestTransliterationAnalysis(unittest.TestCase):
    """TransliterationAnalysis unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTransliterationAnalysis(self):
        """Test TransliterationAnalysis"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TransliterationAnalysis()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.group_add import GroupAdd
globals()['GroupAdd'] = GroupAdd
from smscx_client.model.add_contacts_to_group_with_fields_request import AddContactsToGroupWithFieldsRequest


class TestAddContactsToGroupWithFieldsRequest(unittest.TestCase):
    """AddContactsToGroupWithFieldsRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAddContactsToGroupWithFieldsRequest(self):
        """Test AddContactsToGroupWithFieldsRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AddContactsToGroupWithFieldsRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_numbers_lookup import DataNumbersLookup
from smscx_client.model.info_numbers_lookup import InfoNumbersLookup
globals()['DataNumbersLookup'] = DataNumbersLookup
globals()['InfoNumbersLookup'] = InfoNumbersLookup
from smscx_client.model.numbers_lookup_response import NumbersLookupResponse


class TestNumbersLookupResponse(unittest.TestCase):
    """NumbersLookupResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNumbersLookupResponse(self):
        """Test NumbersLookupResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NumbersLookupResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.api_client import ApiClient, Endpoint as _Endpoint
from smscx_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from smscx_client.model.conversation_details_response import ConversationDetailsResponse
from smscx_client.model.conversation_read_response import ConversationReadResponse
from smscx_client.model.conversation_reply_sms_request import ConversationReplySmsRequest
from smscx_client.model.conversation_reply_sms_response import ConversationReplySmsResponse
from smscx_client.model.conversation_reply_viber_request import ConversationReplyViberRequest
from smscx_client.model.conversation_reply_viber_respone import ConversationReplyViberRespone
from smscx_client.model.conversation_reply_whatsapp_request import ConversationReplyWhatsappRequest
from smscx_client.model.conversation_reply_whatsapp_response import ConversationReplyWhatsappResponse
from smscx_client.model.conversations_list_response import ConversationsListResponse
from smscx_client.model.model400_invalid_param import Model400InvalidParam
from smscx_client.model.model401_unauthorized import Model401Unauthorized
from smscx_client.model.model403_insufficient_scope import Model403InsufficientScope
from smscx_client.model.model404_not_found import Model404NotFound
from smscx_client.model.model500_server_error import Model500ServerError


class ConversationsApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_conversation_endpoint = _Endpoint(
            settings={
                'response_type': (ConversationDetailsResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/conversations/{conversationId}',
                'operation_id': 'get_conversation',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'conversation_id',
                ],
                'required': [
                    'conversation_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'conversation_id',
                ]
            },
            root_map={
                'validations': {
                    ('conversation_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'conversation_id':
                        (str,),
                },
                'attribute_map': {
                    'conversation_id': 'conversationId',
                },
                'location_map': {
                    'conversation_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_converstions_list_endpoint = _Endpoint(
            settings={
                'response_type': (ConversationsListResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/conversations',
                'operation_id': 'get_converstions_list',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.mark_conversation_as_read_endpoint = _Endpoint(
            settings={
                'response_type': (ConversationReadResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/conversations/{conversationId}/read',
                'operation_id': 'mark_conversation_as_read',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'conversation_id',
                ],
                'required': [
                    'conversation_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'conversation_id',
                ]
            },
            root_map={
                'validations': {
                    ('conversation_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'conversation_id':
                        (str,),
                },
                'attribute_map': {
                    'conversation_id': 'conversationId',
                },
                'location_map': {
                    'conversation_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.send_conversation_reply_sms_endpoint = _Endpoint(
            settings={
                'response_type': (ConversationReplySmsResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/conversations/{conversationId}/sms',
                'operation_id': 'send_conversation_reply_sms',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'conversation_id',
                    'conversation_reply_sms_request',
                ],
                'required': [
                    'conversation_id',
                    'conversation_reply_sms_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'conversation_id',
                ]
            },
            root_map={
                'validations': {
                    ('conversation_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'conversation_id':
                        (str,),
                    'conversation_reply_sms_request':
                        (ConversationReplySmsRequest,),
                },
                'attribute_map': {
                    'conversation_id': 'conversationId',
                },
                'location_map': {
                    'conversation_id': 'path',
                    'conversation_reply_sms_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.send_conversation_reply_viber_endpoint = _Endpoint(
            settings={
                'response_type': (ConversationReplyViberRespone,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/conversations/{conversationId}/viber',
                'operation_id': 'send_conversation_reply_viber',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'conversation_id',
                    'conversation_reply_viber_request',
                ],
                'required': [
                    'conversation_id',
                    'conversation_reply_viber_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'conversation_id',
                ]
            },
            root_map={
                'validations': {
                    ('conversation_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'conversation_id':
                        (str,),
                    'conversation_reply_viber_request':
                        (ConversationReplyViberRequest,),
                },
                'attribute_map': {
                    'conversation_id': 'conversationId',
                },
                'location_map': {
                    'conversation_id': 'path',
                    'conversation_reply_viber_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.send_conversation_reply_whatsapp_endpoint = _Endpoint(
            settings={
                'response_type': (ConversationReplyWhatsappResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/conversations/{conversationId}/whatsapp',
                'operation_id': 'send_conversation_reply_whatsapp',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'conversation_id',
                    'conversation_reply_whatsapp_request',
                ],
                'required': [
                    'conversation_id',
                    'conversation_reply_whatsapp_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'conversation_id',
                ]
            },
            root_map={
                'validations': {
                    ('conversation_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'conversation_id':
                        (str,),
                    'conversation_reply_whatsapp_request':
                        (ConversationReplyWhatsappRequest,),
                },
                'attribute_map': {
                    'conversation_id': 'conversationId',
                },
                'location_map': {
                    'conversation_id': 'path',
                    'conversation_reply_whatsapp_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def get_conversation(
        self,
        conversation_id,
        **kwargs
    ):
        """Get conversation  # noqa: E501

        Retrieves the details of a conversation if a valid identifier was provided.    
### Errors for GET `/conversations/{conversationId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1180  |  not_found  | Conversation ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_conversation(conversation_id, async_req=True)
        >>> result = thread.get()

        Args:
            conversation_id (str): Identifier of the conversation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ConversationDetailsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['conversation_id'] = \
            conversation_id
        return self.get_conversation_endpoint.call_with_http_info(**kwargs)

    def get_converstions_list(
        self,
        **kwargs
    ):
        """Get conversations list  # noqa: E501

        Retrieves the list of existing conversations. The list is sorted by last reply date, with the most recent reply appearing first.    If no conversations are available, an empty data object is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_converstions_list(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ConversationsListResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_converstions_list_endpoint.call_with_http_info(**kwargs)

    def mark_conversation_as_read(
        self,
        conversation_id,
        **kwargs
    ):
        """Mark conversation as read  # noqa: E501

        Marks a conversation as read    
### Errors for GET `/conversations/{conversationId}/read`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1180  |  not_found  | Conversation ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.mark_conversation_as_read(conversation_id, async_req=True)
        >>> result = thread.get()

        Args:
            conversation_id (str): Identifier of the conversation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ConversationReadResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['conversation_id'] = \
            conversation_id
        return self.mark_conversation_as_read_endpoint.call_with_http_info(**kwargs)

    def send_conversation_reply_sms(
        self,
        conversation_id,
        conversation_reply_sms_request,
        **kwargs
    ):
        """Send conversation reply via SMS  # noqa: E501

        Sends a reply to a conversation using sms channel.    
### Errors for POST `/conversations/{conversationId}/sms`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1180  |  not_found  | Conversation ID not found |  

|  400 | 1801  |  invalid_param  | The text message is empty or parameter `text` not set |  

|  400 | 1802  |  invalid_param  | The parameter `text` is invalid |  

|  400 | 1111  |  invalid_param  |  Idempotency Id provided is not a valid UUID (v1-v5) |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.send_conversation_reply_sms(conversation_id, conversation_reply_sms_request, async_req=True)
        >>> result = thread.get()

        Args:
            conversation_id (str): Identifier of the conversation
            conversation_reply_sms_request (ConversationReplySmsRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ConversationReplySmsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['conversation_id'] = \
            conversation_id
        kwargs['conversation_reply_sms_request'] = \
            conversation_reply_sms_request
        return self.send_conversation_reply_sms_endpoint.call_with_http_info(**kwargs)

    def send_conversation_reply_viber(
        self,
        conversation_id,
        conversation_reply_viber_request,
        **kwargs
    ):
        """Send conversation reply via Viber  # noqa: E501

        Sends a reply to a conversation using viber channel.    
### Errors for POST `/conversations/{conversationId}/viber`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1180  |  not_found  | Conversation ID not found |  
|  403 | 1181  |  access_denied  | Cannot reply with channel Viber. More than 24 hours since user reply |  

|  400 | 1801  |  invalid_param  | The text message is empty or parameter `text` not set |  

|  400 | 1802  |  invalid_param  | The parameter `text` is invalid |  

|  400 | 1811  |  invalid_param  | Text message too long (max 1000 characters) |  

|  400 | 1111  |  invalid_param  |  Idempotency Id provided is not a valid UUID (v1-v5) |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.send_conversation_reply_viber(conversation_id, conversation_reply_viber_request, async_req=True)
        >>> result = thread.get()

        Args:
            conversation_id (str): Identifier of the conversation
            conversation_reply_viber_request (ConversationReplyViberRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ConversationReplyViberRespone
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['conversation_id'] = \
            conversation_id
        kwargs['conversation_reply_viber_request'] = \
            conversation_reply_viber_request
        return self.send_conversation_reply_viber_endpoint.call_with_http_info(**kwargs)

    def send_conversation_reply_whatsapp(
        self,
        conversation_id,
        conversation_reply_whatsapp_request,
        **kwargs
    ):
        """Send conversation reply via Whatsapp  # noqa: E501

        Sends a reply to a conversation using whatsapp channel.    
### Errors for POST `/conversations/{conversationId}/whatsapp`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1180  |  not_found  | Conversation ID not found |  
|  403 | 1182  |  access_denied  | Cannot reply with channel Whatsapp. More than 24 hours since user reply |  

|  400 | 1801  |  invalid_param  | The text message is empty or parameter `text` not set |  

|  400 | 1802  |  invalid_param  | The parameter `text` is invalid |  

|  400 | 1811  |  invalid_param  | Text message too long (max 1000 characters) |  

|  400 | 1111  |  invalid_param  |  Idempotency Id provided is not a valid UUID (v1-v5) |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.send_conversation_reply_whatsapp(conversation_id, conversation_reply_whatsapp_request, async_req=True)
        >>> result = thread.get()

        Args:
            conversation_id (str): Identifier of the conversation
            conversation_reply_whatsapp_request (ConversationReplyWhatsappRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ConversationReplyWhatsappResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['conversation_id'] = \
            conversation_id
        kwargs['conversation_reply_whatsapp_request'] = \
            conversation_reply_whatsapp_request
        return self.send_conversation_reply_whatsapp_endpoint.call_with_http_info(**kwargs)




import sys
import unittest

import smscx_client
from smscx_client.model.data_receive_sms import DataReceiveSms


class TestDataReceiveSms(unittest.TestCase):
    """DataReceiveSms unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDataReceiveSms(self):
        """Test DataReceiveSms"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DataReceiveSms()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import unittest

import smscx_client
from smscx_client.api.originators_api import OriginatorsApi  # noqa: E501


class TestOriginatorsApi(unittest.TestCase):
    """OriginatorsApi unit test stubs"""

    def setUp(self):
        self.api = OriginatorsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_originator(self):
        """Test case for create_originator

        Create new originator  # noqa: E501
        """
        pass

    def test_delete_originator(self):
        """Test case for delete_originator

        Delete originator  # noqa: E501
        """
        pass

    def test_get_originators_list(self):
        """Test case for get_originators_list

        Get originators list  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import unittest

import smscx_client
from smscx_client.api.numbers_api import NumbersApi  # noqa: E501


class TestNumbersApi(unittest.TestCase):
    """NumbersApi unit test stubs"""

    def setUp(self):
        self.api = NumbersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_rent(self):
        """Test case for cancel_rent

        Cancel rent for phone number  # noqa: E501
        """
        pass

    def test_get_available_numbers(self):
        """Test case for get_available_numbers

        Get available numbers for rent  # noqa: E501
        """
        pass

    def test_get_bulk_lookup_status(self):
        """Test case for get_bulk_lookup_status

        Get Bulk Lookup result  # noqa: E501
        """
        pass

    def test_get_inbound_sms(self):
        """Test case for get_inbound_sms

        Get inbound SMS from rented number  # noqa: E501
        """
        pass

    def test_get_rent_status(self):
        """Test case for get_rent_status

        Get status of rent  # noqa: E501
        """
        pass

    def test_get_rented_numbers(self):
        """Test case for get_rented_numbers

        Get list of your rented numbers  # noqa: E501
        """
        pass

    def test_get_single_lookup_status(self):
        """Test case for get_single_lookup_status

        Get Single Lookup result  # noqa: E501
        """
        pass

    def test_lookup_number(self):
        """Test case for lookup_number

        Lookup number  # noqa: E501
        """
        pass

    def test_lookup_numbers(self):
        """Test case for lookup_numbers

        Lookup numbers in bulk  # noqa: E501
        """
        pass

    def test_renew_rent(self):
        """Test case for renew_rent

        Renew rent for phone number  # noqa: E501
        """
        pass

    def test_rent_number(self):
        """Test case for rent_number

        Rent phone number  # noqa: E501
        """
        pass

    def test_validate_number(self):
        """Test case for validate_number

        Validate number  # noqa: E501
        """
        pass

    def test_validate_numbers(self):
        """Test case for validate_numbers

        Validate numbers in bulk  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import unittest

import smscx_client
from smscx_client.api.optouts_api import OptoutsApi  # noqa: E501


class TestOptoutsApi(unittest.TestCase):
    """OptoutsApi unit test stubs"""

    def setUp(self):
        self.api = OptoutsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_contact_to_optouts_list(self):
        """Test case for add_contact_to_optouts_list

        Add contact to optouts list  # noqa: E501
        """
        pass

    def test_delete_contact_from_optouts_list(self):
        """Test case for delete_contact_from_optouts_list

        Delete contact from optouts list  # noqa: E501
        """
        pass

    def test_export_optouts_to_csv(self):
        """Test case for export_optouts_to_csv

        Export optouts to CSV  # noqa: E501
        """
        pass

    def test_export_optouts_to_xlsx(self):
        """Test case for export_optouts_to_xlsx

        Export optouts to XLSX  # noqa: E501
        """
        pass

    def test_get_optouts_list(self):
        """Test case for get_optouts_list

        Get optouts list  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
